==> flowd-0.7.tar.gz: flowd-0.7/setup.py <==
#!/usr/bin/env python

# Copyright (c) 2004 Damien Miller <djm@mindrot.org>
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.

# $Id: setup.py,v 1.5 2004/11/03 04:02:06 djm Exp $

import sys
from distutils.core import setup, Extension

if __name__ == '__main__':
	if sys.hexversion < 0x02030000:
		print >> sys.stderr, "error: " + \
		    "flowd.py requires python < 2.3"
		sys.exit(1)

	flowd_serialiser = Extension('flowd_serialiser',
		sources = ['flowd_python.c'],
		define_macros = [('PROGVER', '"0.7"')],
		libraries = ['flowd'],
		library_dirs = ['.', '../..'])
	setup(	name = "flowd",
		version = "0.7",
		author = "Damien Miller",
		author_email = "djm@mindrot.org",
		url = "http://www.mindrot.org/flowd.html",
		description = "Interface to flowd flow storage format",
		long_description = """\
This is an API to parse the binary flow logs written by the flowd network flow
collector.
""",
		license = "BSD",
		py_modules = ['flowd'],
		ext_modules = [flowd_serialiser]
	     )

==> flowd-0.8.tar.gz: flowd-0.8/setup.py <==
#!/usr/bin/env python

# Copyright (c) 2004 Damien Miller <djm@mindrot.org>
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.

# $Id: setup.py,v 1.7 2004/11/08 23:23:58 djm Exp $

import sys
from distutils.core import setup, Extension

if __name__ == '__main__':
	if sys.hexversion < 0x02030000:
		print >> sys.stderr, "error: " + \
		    "flowd.py requires python >= 2.3"
		sys.exit(1)

	flowd_serialiser = Extension('flowd_serialiser',
		sources = ['flowd_python.c'],
		define_macros = [('PROGVER', '"0.8"')],
		libraries = ['flowd'],
		library_dirs = ['.', '../..'])
	setup(	name = "flowd",
		version = "0.8",
		author = "Damien Miller",
		author_email = "djm@mindrot.org",
		url = "http://www.mindrot.org/flowd.html",
		description = "Interface to flowd flow storage format",
		long_description = """\
This is an API to parse the binary flow logs written by the flowd network flow
collector.
""",
		license = "BSD",
		py_modules = ['flowd'],
		ext_modules = [flowd_serialiser]
	     )
